##
##  gzip.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         gzip
Summary:      De-/Compression with GZIP Algorithm
URL:          http://www.gzip.org/
Vendor:       Jean-loup Gailly, Mark Adler
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        CORE
Group:        Compression
License:      GPL
Version:      1.14
Release:      20250410

#   list of sources
Source0:      http://ftp.gnu.org/gnu/gzip/gzip-%{version}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101

%description
    GNU zip (gzip) is a compression utility designed to be a replacement
    for the traditional Unix utility compress(1). Its main advantages
    over compress(1) are much better compression and freedom from
    patented algorithms. gzip produces files with a .gz extension.
    gunzip can decompress files created by gzip, compress and pack. The
    detection of the input format is automatic. The format of the .gz
    files generated by gzip is described in RFCs (Request For Comments)
    1951 and 1952.

%track
    prog gzip = {
        version   = %{version}
        url       = http://ftp.gnu.org/gnu/gzip/
        regex     = gzip-(__VER__)\.tar(\.gz)?
    }

%prep
    %setup -q

%build
    #   configure package
    echo "ac_cv_path_shell=%{l_bash}" >config.cache
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    GREP="grep" \
    ./configure \
        --cache-file=./config.cache \
        --prefix=%{l_prefix} \
        --datarootdir=%{l_prefix}

    #   build package
    %{l_make} %{l_mflags -O}

%install

    #   install package
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"

    #   strip down installation
    rm -f $RPM_BUILD_ROOT%{l_prefix}/info/dir
    rm -f $RPM_BUILD_ROOT%{l_prefix}/lib/charset.alias
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* 2>/dev/null || true

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

